@@ -243,7 +243,7 @@ sub configurator {
 	  $options->{'chord-grids'} ? "all" : 0;
     }
 
-    for ( qw( transpose transcode decapo lyrics-only ) ) {
+    for ( qw( transpose transcode decapo lyrics-only strict ) ) {
 	next unless defined $options->{$_};
 	$cfg->{settings}->{$_} = $options->{$_};
     }
@@ -298,7 +298,7 @@ sub get_config {
     }
     elsif ( $file =~ /\.prp$/i ) {
 	if ( -e -f -r $file ) {
-	    require Data::Properties;
+	    require App::Music::ChordPro::Config::Properties;
 	    my $cfg = new Data::Properties;
 	    $cfg->parse_file($file);
 	    return $cfg->data;
@@ -499,10 +499,11 @@ sub _augment {
 
     for my $key ( keys(%$hash) ) {
 
-	warn("Config error: unknown item $path$key\n")
+	warn("Config augment error: unknown item $path$key\n")
 	  unless exists $self->{$key}
 	    || $path eq "pdf.fontconfig."
-	    || $path =~ "^meta\."
+	    || $path =~ /^pdf\.fonts\./
+	    || $path =~ /^meta\./
 	    || $key =~ /^_/;
 
 	# Hash -> Hash.
@@ -599,7 +600,7 @@ sub _reduce {
 	my %hh = map { $_ => 1 } keys(%$self), keys(%$orig);
 	for my $key ( sort keys(%hh) ) {
 
-	    warn("Config error: unknown item $path$key\n")
+	    warn("Config reduce error: unknown item $path$key\n")
 	      unless exists $self->{$key}
 		|| $key =~ /^_/;
 
@@ -740,6 +741,7 @@ sub hmerge($$;$) {
 	warn("Config error: unknown item $path$key\n")
 	  unless exists $res{$key}
 	    || $path eq "pdf.fontconfig."
+	    || $path =~ /^pdf\.fonts\./
 	    || $path =~ /^meta\./
 	    || $key =~ /^_/;
 
@@ -902,6 +904,8 @@ sub default_config() {
 
     // General settings, to be changed by configs and command line.
     "settings" : {
+      // Strict behaviour.
+      "strict" : true,
       // Add line info for backend diagnostics.
       "lineinfo" : true,
       // Titles flush: default center.
